---
name: Bug report (including performance and build issues)
about: Help us find mistakes in the GeometricKernels code base
labels: bug
---

<!-- Lines like this are comments and will be invisible -->

# Bug / performance issue / build issue

<!-- A clear and concise description of what the bug is. -->

## To reproduce

**Minimal, reproducible example**
<!-- We need to be able to reproduce the bug by simply copy and pasting your code -->
```python
# This is the place for your code that reproduces the bug.
# Please make sure it does not depend on external libraries (beyond GeometricKernels's own requirements) or specific datasets, and the smaller, the better :)
# For help on how to write a good bug report, see https://stackoverflow.com/help/minimal-reproducible-example
```

**Stack trace, or error message**
```
// Paste the full stack trace/error message here
```

## Expected behavior

<!-- A clear and concise description of what you expected to happen. -->

## System information

* GeometricKernels version
* TensorFlow/PyTorch/Jax version
* Python version
* Operating system

## Additional context

<!-- Add any other context about the problem here. -->